@@ -11,7 +11,6 @@ from pyqt_svg_label import SvgLabel
 
 from pyqt_windows_buttons_widget import WindowsButtonsWidget
 from pyqt_mac_buttons_widget import MacButtonsWidget
-from pyqt_resource_helper import PyQtResourceHelper
 import absresgetter
 
 
@@ -86,7 +85,7 @@ class CustomTitlebarWindow(FramelessWindow):
         # font family: arial
         appFont.setFamily('Arial')
         # font size: 9~12
-        appFont.setPointSize(min(12, max(9, appFont.pointSize() * qApp.devicePixelRatio())))
+        appFont.setPointSize(min(12, max(9, appFont.pointSize() * qApp.desktop().logicalDpiX()/96.0)))
         # font style strategy: antialiasing
         appFont.setStyleStrategy(QFont.PreferAntialias)
         qApp.setFont(appFont)
